/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "XSLTProcessor.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomXSLTProcessor.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomXSLTProcessor.h"
#include "gdom/PrivateIntGdomXSLTProcessor.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::XSLTProcessor* obj)
{
    return WebCore::cacheDOMObject<WebCore::XSLTProcessor, GDOMXSLTProcessor>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMXSLTProcessor::GDOMXSLTProcessor(PassRefPtr<WebCore::XSLTProcessor> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMXSLTProcessor::~GDOMXSLTProcessor()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}


/* XXX TODO: custom function gdom_xslt_processor_import_stylesheet */


/* XXX TODO: custom function gdom_xslt_processor_transform_to_fragment */


/* XXX TODO: custom function gdom_xslt_processor_transform_to_document */


/* XXX TODO: custom function gdom_xslt_processor_set_parameter */


/* XXX TODO: custom function gdom_xslt_processor_get_parameter */


/* XXX TODO: custom function gdom_xslt_processor_remove_parameter */

void
gdom_xslt_processor_clear_parameters (GdomXSLTProcessor *thiz)
{
    g_return_if_fail (thiz);
    WebCore::XSLTProcessor * item = (gdom_xslt_processor_get_private(thiz));
    g_return_if_fail (item);
    item->clearParameters();

}

void
gdom_xslt_processor_reset (GdomXSLTProcessor *thiz)
{
    g_return_if_fail (thiz);
    WebCore::XSLTProcessor * item = (gdom_xslt_processor_get_private(thiz));
    g_return_if_fail (item);
    item->reset();

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "XSLTProcessor.h"
#include <gdom/GdomXSLTProcessor.h>
#include <gdom/PrivateGdomXSLTProcessor.h>
#include <gdom/PrivateIntGdomXSLTProcessor.h>
#include <gdom/GdomXSLTProcessorprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomXSLTProcessor, gdom_xslt_processor, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomXSLTProcessorPrivate {
    class WebCore::XSLTProcessor *item;
};

#define GDOM_XSLT_PROCESSOR_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_XSLT_PROCESSOR, GdomXSLTProcessorPrivate))
*/
G_END_DECLS
WebCore::XSLTProcessor *
gdom_xslt_processor_get_private(GdomXSLTProcessor *request)
{
    GDOMXSLTProcessor *res;
    res = static_cast<GDOMXSLTProcessor*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::XSLTProcessor*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
};


static void gdom_xslt_processor_finalize(GObject* object)
{
    /*GdomXSLTProcessor* request = GDOM_XSLT_PROCESSOR(object);*/
    /*GdomXSLTProcessorPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_xslt_processor_parent_class)->finalize(object);
}

static void gdom_xslt_processor__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomXSLTProcessor *self = GDOM_XSLT_PROCESSOR(object);
    WebCore::XSLTProcessor * gself = (gdom_xslt_processor_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_xslt_processor__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomXSLTProcessor *self = GDOM_XSLT_PROCESSOR(object);
    WebCore::XSLTProcessor * gself = (gdom_xslt_processor_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_xslt_processor_class_init(GdomXSLTProcessorClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_xslt_processor_finalize;
    g_klass->set_property = gdom_xslt_processor__set_property_fn;
    g_klass->get_property = gdom_xslt_processor__get_property_fn;





    /*g_type_class_remove_private(requestClass, sizeof(GdomXSLTProcessorPrivate));*/
}

static void gdom_xslt_processor_init(GdomXSLTProcessor* request)
{
    /*GdomXSLTProcessorPrivate* priv = GDOM_XSLT_PROCESSOR_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

